@@ -1,45 +1,19 @@
-/****************************************************************************
-**
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
-**
-** This file is part of the test suite of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL21$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+/*
+    This file is part of the test suite of the Qt Toolkit.
+    SPDX-FileCopyrightText: 2014 Digia Plc and/or its subsidiary(-ies) <http://www.qt-project.org/legal>
+
+    SPDX-License-Identifier: LGPL-2.1-only WITH Qt-LGPL-exception-1.1 OR LGPL-3.0-only WITH Qt-LGPL-exception-1.1 OR LicenseRef-Qt-Commercial
+*/
 
 #include "util.h"
 
-#include <QtQml/QQmlComponent>
-#include <QtQml/QQmlError>
-#include <QtQml/QQmlContext>
-#include <QtQml/QQmlEngine>
-#include <QtCore/QTextStream>
-#include <QtCore/QDebug>
-#include <QtCore/QMutexLocker>
+#include <QQmlComponent>
+#include <QQmlError>
+#include <QQmlContext>
+#include <QQmlEngine>
+#include <QTextStream>
+#include <QMutexLocker>
+#include <QTest>
 
 QQmlDataTest *QQmlDataTest::m_instance = nullptr;
 
@@ -91,8 +65,8 @@ QByteArray QQmlDataTest::msgComponentError(const QQmlComponent &c,
         if (QQmlContext *context = c.creationContext())
             engine = context->engine();
     if (engine) {
-        str << " Import paths: (" << engine->importPathList().join(QStringLiteral(", "))
-            << ") Plugin paths: (" << engine->pluginPathList().join(QStringLiteral(", "))
+        str << " Import paths: (" << engine->importPathList().join(QLatin1String(", "))
+            << ") Plugin paths: (" << engine->pluginPathList().join(QLatin1String(", "))
             << ')';
     }
     return result.toLocal8Bit();
