@@ -1,24 +1,8 @@
 /*
-    Copyright (C) 2010 by BetterInbox <contact@betterinbox.com>
-    Original author: Gregory Schlomoff <greg@betterinbox.com>
+    SPDX-FileCopyrightText: 2010 BetterInbox <contact@betterinbox.com>
+    SPDX-FileContributor: Gregory Schlomoff <greg@betterinbox.com>
 
-    Permission is hereby granted, free of charge, to any person obtaining a copy
-    of this software and associated documentation files (the "Software"), to deal
-    in the Software without restriction, including without limitation the rights
-    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-    copies of the Software, and to permit persons to whom the Software is
-    furnished to do so, subject to the following conditions:
-
-    The above copyright notice and this permission notice shall be included in
-    all copies or substantial portions of the Software.
-
-    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-    THE SOFTWARE.
+    SPDX-License-Identifier: MIT
 */
 
 #include "DeclarativeMimeData.h"
@@ -52,7 +36,8 @@ DeclarativeMimeData::DeclarativeMimeData(const QMimeData* copy)
     m_source(nullptr)
 {
     // Copy the standard MIME data
-    foreach(QString format, copy->formats()) {
+    const auto formats = copy->formats();
+    for (const QString &format : formats) {
         QMimeData::setData(format, copy->data(format));
     }
 
@@ -90,7 +75,8 @@ void DeclarativeMimeData::setUrl(const QUrl &url)
 QJsonArray DeclarativeMimeData::urls() const
 {
     QJsonArray varUrls;
-    foreach (const QUrl &url, QMimeData::urls()) {
+    const auto lstUrls = QMimeData::urls();
+    for (const QUrl &url : lstUrls) {
         varUrls.append(url.toString());
     }
     return varUrls;
@@ -100,7 +86,7 @@ void DeclarativeMimeData::setUrls(const QJsonArray &urls)
 {
     QList<QUrl> urlList;
     urlList.reserve(urls.size());
-    foreach (const QVariant &varUrl, urls) {
+    for (const QVariant &varUrl : urls) {
         urlList << varUrl.toUrl();
     }
     QMimeData::setUrls(urlList);
