@@ -1,22 +1,8 @@
 /*
-Copyright 2013 Marco Martin <mart@kde.org>
-Copyright 2014 Sebastian Kügler <sebas@kde.org>
+    SPDX-FileCopyrightText: 2013 Marco Martin <mart@kde.org>
+    SPDX-FileCopyrightText: 2014 Sebastian Kügler <sebas@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "kuserproxy.h"
@@ -26,9 +12,7 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include <QTextStream>
 #include <QUrl>
 
-#include <KDirWatch>
 
-#include <QDebug>
 
 const QString etcPasswd = QStringLiteral("/etc/passwd");
 const QString accountsServiceIconPath = QStringLiteral("/var/lib/AccountsService/icons");
