@@ -1,28 +1,14 @@
 /*
- *    Copyright 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
- *
- *    This library is free software; you can redistribute it and/or
- *    modify it under the terms of the GNU Library General Public
- *    License as published by the Free Software Foundation; either
- *    version 2 of the License, or (at your option) any later version.
- *
- *    This library is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *    Library General Public License for more details.
- *
- *    You should have received a copy of the GNU Library General Public License
- *    along with this library; see the file COPYING.LIB.  If not, write to
- *    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *    Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef CLIPBOARD_H
 #define CLIPBOARD_H
 
 #include <QClipboard>
 #include <QVariant>
-#include <QMimeData>
 
 class ClipboardPrivate;
 
@@ -45,7 +31,7 @@ class Clipboard : public QObject
     Q_PROPERTY(QStringList formats READ formats NOTIFY contentChanged)
 
     public:
-        explicit Clipboard(QObject* parent = 0);
+        explicit Clipboard(QObject* parent = nullptr);
 
         QClipboard::Mode mode() const;
         void setMode(QClipboard::Mode mode);
