@@ -1,28 +1,15 @@
 /*
- *   Copyright 2012 by Aleix Pol Gonzalez <aleixpol@blue-systems.com>
- * 
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "columnproxymodel.h"
 
 ColumnProxyModel::ColumnProxyModel(QObject* parent)
     : QAbstractListModel(parent)
     , m_column(0)
-    , m_sourceModel(0)
+    , m_sourceModel(nullptr)
 {}
 
 void ColumnProxyModel::setSourceModel(QAbstractItemModel* sourceModel)
@@ -167,7 +154,7 @@ void ColumnProxyModel::sourceDestroyed(QObject* source)
     Q_ASSERT(source==m_sourceModel);
     
     beginResetModel();
-    m_sourceModel = 0;
+    m_sourceModel = nullptr;
     endResetModel();
 }
 
