@@ -1,22 +1,9 @@
 /*
- *   Copyright (C) 2015 by Eike Hein <hein@kde.org>
- *   Copyright (C) 2015 Marco Martin <notmart@gmail.com>
- *
- *    This library is free software; you can redistribute it and/or
- *    modify it under the terms of the GNU Library General Public
- *    License as published by the Free Software Foundation; either
- *    version 2 of the License, or (at your option) any later version.
- *
- *    This library is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *    Library General Public License for more details.
- *
- *    You should have received a copy of the GNU Library General Public License
- *    along with this library; see the file COPYING.LIB.  If not, write to
- *    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *    Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2015 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2015 Marco Martin <notmart@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "eventgenerator.h"
 
@@ -78,11 +65,7 @@ void EventGenerator::sendWheelEvent(QQuickItem *item, int x, int y, const QPoint
 
     QPointF pos(x, y);
     QPointF globalPos(item->window()->mapToGlobal(item->mapToScene(pos).toPoint()));
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    QWheelEvent ev(pos, globalPos, pixelDelta, angleDelta, /* qt4Delta */ 0, /* qt4Orientation */ Qt::Horizontal, buttons, modifiers);
-#else
     QWheelEvent ev(pos, globalPos, pixelDelta, angleDelta, buttons, modifiers, Qt::ScrollUpdate, false /*not inverted*/);
-#endif
     QGuiApplication::sendEvent(item, &ev);
 }
 
