@@ -1,30 +1,15 @@
 /*
- * This file is part of the KDE project
- *
- * Copyright © 2014 Fredrik Höglund <fredrik@kde.org>
- * Copyright © 2014 Marco Martin <mart@kde.org>
- * Copyright © 2015 David Edmundson <davidedmundson@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+    This file is part of the KDE project
+
+    SPDX-FileCopyrightText: 2014 Fredrik Höglund <fredrik@kde.org>
+    SPDX-FileCopyrightText: 2014 Marco Martin <mart@kde.org>
+    SPDX-FileCopyrightText: 2015 David Edmundson <davidedmundson@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "plotter.h"
 
-#include <QGuiApplication>
-#include <QWindow>
 
 #include <QOpenGLContext>
 #include <QOpenGLShaderProgram>
@@ -38,9 +23,6 @@
 #include <QSGTexture>
 #include <QSGSimpleTextureNode>
 
-#include <QQuickWindow>
-#include <QQuickView>
-#include <QQuickItem>
 
 #include <QDebug>
 
@@ -909,6 +891,11 @@ void Plotter::normalizeData()
     }
     m_mutex.unlock();
 
+    if (adjustedMin > 0.0 && adjustedMax > 0.0)
+        adjustedMin = 0.0;
+
+    if (adjustedMin < 0.0 && adjustedMax < 0.0)
+        adjustedMax = 0.0;
 
     if (m_autoRange || m_rangeMax > m_rangeMin) {
         if (!m_autoRange) {
