@@ -1,23 +1,8 @@
 /*
-   This file is part of the KDE libraries
-
-   Copyright (C) 2015 Marco Martin <mart@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2015 Marco Martin <mart@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef QUICKVIEWSHAREDENGINE_H
@@ -38,6 +23,11 @@ namespace KQuickAddons {
 
 class QuickViewSharedEnginePrivate;
 
+/**
+ * @class KQuickAddons::QuickViewSharedEngine quickviewsharedengine.h KQuickAddons/QuickViewSharedEngine
+ *
+ * TODO
+ */
 class QUICKADDONS_EXPORT QuickViewSharedEngine : public QQuickWindow
 {
     Q_OBJECT
@@ -45,16 +35,16 @@ class QUICKADDONS_EXPORT QuickViewSharedEngine : public QQuickWindow
     Q_PROPERTY(ResizeMode resizeMode READ resizeMode WRITE setResizeMode NOTIFY resizeModeChanged)
     Q_PROPERTY(QQmlComponent::Status status READ status NOTIFY statusChanged)
     Q_PROPERTY(QUrl source READ source WRITE setSource NOTIFY sourceChanged)
-    Q_ENUMS(ResizeMode)
 
 public:
     enum ResizeMode {
         SizeViewToRootObject,
         SizeRootObjectToView
     };
+    Q_ENUM(ResizeMode)
 
-    explicit QuickViewSharedEngine(QWindow *parent = 0);
-    ~QuickViewSharedEngine();
+    explicit QuickViewSharedEngine(QWindow *parent = nullptr);
+    ~QuickViewSharedEngine() override;
 
     /**
      * Installs a translation domain for all
@@ -92,7 +82,7 @@ public:
     void setResizeMode(ResizeMode);
 
 protected:
-    void resizeEvent(QResizeEvent *e) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent *e) override;
 
 public Q_SLOTS:
     void setSource(const QUrl &url);
